+++
title = "The design of high performance mechatronics - third revised edition"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Reference Books]({{< relref "reference_books" >}}), [Dynamic Error Budgeting]({{< relref "dynamic_error_budgeting" >}})

Reference
: ([Schmidt, Schitter, and Rankers 2020](#org9aaa5b5))

Author(s)
: Schmidt, R. M., Schitter, G., & Rankers, A.

Year
: 2020


## Applied Physics in Mechatronic Systems {#applied-physics-in-mechatronic-systems}


### Introduction {#introduction}


### Mechanics {#mechanics}

> The core of a mechatronic system is its mechanical construction and in spite of many decade of excellent designs, optimizing the mechanical structure in strength, mass and endurance, the mechanical behavior will always remain the limiting factor of the performance of any mechatronic system.


#### Coordinate Systems {#coordinate-systems}


##### Cartesian Coordinate System {#cartesian-coordinate-system}


##### Generalised Coordinate System {#generalised-coordinate-system}


##### Modal Coordinate System {#modal-coordinate-system}


#### Force and Motion {#force-and-motion}

> _Statics_ deals with the stress levels that are present in the mechanical system when (quasi-)static forces are exerted on it.
> It analyses the linear and non-linear strain effects that are caused by elastic and plastic deformation under these stress levels.
>
> _Dynamics_ deals with the behaviour of the mechanical system under changing forces, while often the effects are linearised and limited to strain levels well below any irreversible plastic deformation.
> One should however be aware that another non-destructive source of non-linearity is found in a tried important field of mechanics, called _kinematics_.
> The relation between angles and positions is often non-linear in such a mechanism, because of the changing angles, and controlling these often requires special precautions to overcome the inherent non-linearities by linearisation around actual position and adapting the optimal settings of the controller to each position.


##### Galilei and Newton's Laws of Motion {#galilei-and-newton-s-laws-of-motion}


##### Hooke's Law of Elasticity {#hooke-s-law-of-elasticity}


##### Lagrange Equations of Motion {#lagrange-equations-of-motion}


### Electricity and Magnetism {#electricity-and-magnetism}


#### Electric Field {#electric-field}

<a id="org9d23fdb"></a>

{{< figure src="/ox-hugo/schmidt20_electrical_field.svg" caption="Figure 1: Charges have an electric field" >}}


##### Potential Difference and Capacitance {#potential-difference-and-capacitance}


##### Electric Current in Conductive Material {#electric-current-in-conductive-material}


#### Magnetism and the Maxwell Equations {#magnetism-and-the-maxwell-equations}


#### Electric Sources and Elements {#electric-sources-and-elements}


##### Voltage Source {#voltage-source}


##### Summary on Voltage and Current {#summary-on-voltage-and-current}


##### Electric Power {#electric-power}


##### Ohm's Law {#ohm-s-law}


##### Practical Values and Summary {#practical-values-and-summary}


### Signal Theory and Wave Propagation {#signal-theory-and-wave-propagation}


#### The Concept of Frequency {#the-concept-of-frequency}


##### Random Signals or Noise {#random-signals-or-noise}


##### Power of Alternating Signals {#power-of-alternating-signals}


#### Use of Complex Numbers {#use-of-complex-numbers}


##### Dynamic Impedance and Ohm's Law {#dynamic-impedance-and-ohm-s-law}


##### Power in Dynamic Impedance {#power-in-dynamic-impedance}


##### Capacitive Impedance {#capacitive-impedance}


##### Inductive Impedance {#inductive-impedance}


#### Energy Propagation in Waves {#energy-propagation-in-waves}


##### Mechanical Waves {#mechanical-waves}


##### Wave Equation {#wave-equation}


##### Electromagnetic Waves {#electromagnetic-waves}


##### Reflection of Waves {#reflection-of-waves}


##### Standing Waves {#standing-waves}


#### Fourier Decomposition of Alternating Signals {#fourier-decomposition-of-alternating-signals}


##### Fourier in the frequency-domain {#fourier-in-the-frequency-domain}


##### Triangle Waveform {#triangle-waveform}


##### Sawtooth Waveform {#sawtooth-waveform}


##### Square Waveform {#square-waveform}


##### Non-Continuous Alternating Signals {#non-continuous-alternating-signals}


### Dynamic System Analysis and Modelling {#dynamic-system-analysis-and-modelling}


#### Laplace-Transform {#laplace-transform}


##### Poles and Zeros {#poles-and-zeros}


##### Order of a Dynamic System {#order-of-a-dynamic-system}


#### Dynamic Responses in the time-domain {#dynamic-responses-in-the-time-domain}


##### Step Response {#step-response}


##### Impulse Response {#impulse-response}


##### Impulse Response and Pole Location {#impulse-response-and-pole-location}


#### Dynamic Responses in the frequency-domain {#dynamic-responses-in-the-frequency-domain}


##### Frequency or Fourier-Domain Responses {#frequency-or-fourier-domain-responses}


##### Domain Notation of Dynamic Functions {#domain-notation-of-dynamic-functions}


##### Frequency Response Plots {#frequency-response-plots}


##### Bode Plot {#bode-plot}


##### Nyquist Plot {#nyquist-plot}


##### Limitation to LTI Systems {#limitation-to-lti-systems}


## Dynamics of Motion Systems {#dynamics-of-motion-systems}


### Introduction {#introduction}


### Stiffness {#stiffness}


#### Importance of Stiffness for Precision {#importance-of-stiffness-for-precision}


#### Active Stiffness {#active-stiffness}


### Mass-Spring Systems with Damping {#mass-spring-systems-with-damping}


#### Dynamic Compliance {#dynamic-compliance}


##### Compliance of a Spring {#compliance-of-a-spring}


##### Compliance of a Damper {#compliance-of-a-damper}


##### Compliance of a Body {#compliance-of-a-body}


##### Dynamic Stiffness {#dynamic-stiffness}


##### Lumping the Dynamic Elements {#lumping-the-dynamic-elements}


#### Transfer Function of Compliance {#transfer-function-of-compliance}


##### Damped Mass-Spring System. {#damped-mass-spring-system-dot}


##### Magnitude {#magnitude}


##### Phase {#phase}


##### Bode Plot {#bode-plot}


#### Effects of Damping {#effects-of-damping}


##### Damped Resonance and Aperiodic Damping {#damped-resonance-and-aperiodic-damping}


##### Poles and Critical Damping {#poles-and-critical-damping}


##### Quality-Factor Q and Energy in Resonance {#quality-factor-q-and-energy-in-resonance}


#### Transmissibility {#transmissibility}


#### Fourth-Order Dynamic System {#fourth-order-dynamic-system}


##### Analytical Description {#analytical-description}


##### Multiplicative Expression {#multiplicative-expression}


##### Effect of Different Mass Ratios {#effect-of-different-mass-ratios}


### Modal Decomposition {#modal-decomposition}


#### Eigenmodes of Two-Body Mass-Spring System {#eigenmodes-of-two-body-mass-spring-system}


#### Theory of Modal Decomposition {#theory-of-modal-decomposition}


##### Multi Degree of Freedom Equation of Motion {#multi-degree-of-freedom-equation-of-motion}


##### Eigenvalues and Eigenvectors {#eigenvalues-and-eigenvectors}


##### Modal Coordinates {#modal-coordinates}


##### Resulting Transfer Function {#resulting-transfer-function}


#### Graphical Representation of Mode-Shapes {#graphical-representation-of-mode-shapes}


##### Traditional Representation {#traditional-representation}


##### Lever Representation {#lever-representation}


##### General System {#general-system}


##### User-Defined Physical DOF {#user-defined-physical-dof}


#### Physical Meaning of Modal Parameters {#physical-meaning-of-modal-parameters}


##### Two-Body Mass-Spring System {#two-body-mass-spring-system}


##### Planar Flexibly Guided System {#planar-flexibly-guided-system}


#### A Pragmatic View on Sensitivity Analysis {#a-pragmatic-view-on-sensitivity-analysis}


##### Example of Two Body Mass-Spring System {#example-of-two-body-mass-spring-system}


##### Example of Slightly Damped Resonance {#example-of-slightly-damped-resonance}


#### Suspension and Rigid-Body Modes {#suspension-and-rigid-body-modes}


##### Quasi Rigid-Body Suspension mode {#quasi-rigid-body-suspension-mode}


### Mechanical Frequency Response {#mechanical-frequency-response}


#### Multiple eigenmodes {#multiple-eigenmodes}


#### Characteristic Frequency Responses {#characteristic-frequency-responses}


##### Frequency Response Type I {#frequency-response-type-i}


##### Frequency Response Type II {#frequency-response-type-ii}


##### Frequency Response Type III {#frequency-response-type-iii}


##### Frequency Response Type IV {#frequency-response-type-iv}


#### Example Systems with Type I/II/IV Response {#example-systems-with-type-i-ii-iv-response}


##### Planar Moving Body on Compliant Spring {#planar-moving-body-on-compliant-spring}


##### H-drive Waferstage {#h-drive-waferstage}


### Summary on Dynamics {#summary-on-dynamics}

<summary>
In this chapter some important lessons have been learned, which are summarised as follows:

-   Stiffness, whether it is created mechanically or by means of a control system, is determinative for precision
-   Every mechanical structure can be modelled as a combination of bodies, springs and dampers, either as separate bodies or as finite elements within a body
-   Phase is prominent factor regarding the possibility to control the motion of a mechanical system
-   The quality factor \\(Q\\) and damping ratio \\(\xi\\) are inverse proportional. Each have their practical value.
-   A damping placed in parallel with a lumped mass-spring system limits the magnitude of the resonance at the natural frequency.
    However, it also increases the transmissibility at frequencies above the native frequency.
-   The dynamic behavior of a complex system and its response to a stimulus can be derived and understood by viewing it as a superposition of contributions of its eigenmodes, each with its own mode-shape, eigenfrequency, modal parameters and damping.
-   The position of the actuator and the sensors determine the observability and controllability of the different eigenmodes, which is characterised by four typical frequency response.
-   A precision design requires a careful lay-out of all elements, considering the eigenmodes.
-   Modal analysis is a powerful and widely applied tool to investigate the dynamics of a mechanical structure.

Finally it can be concluded, that these insights help in designing actively controlled dynamic motion systems with optimally located actuators and sensors, which reduce the sensitivity for modal dynamic problems.
</summary>


## Motion Control {#motion-control}


### Introduction {#introduction}


### A Walk around the Control Loop {#a-walk-around-the-control-loop}

Figure [2](#orgee3bd80) shows a basic control loop of a positioning system.
First, the A/D and D/A converters are used to translate analog signals into time-discrete digital signals and vice versa.
Secondly, the impact locations of several disturbances are shown, which play a large role in determining what reqwuirements the controller needs to fulfil.
The core of the control system is the _plant_, which is the physical system that needs to be controlled.

<a id="table--tab:walk-control-loop"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:walk-control-loop">Table 1</a></span>:
  Symbols used in Figure <a href="#orgee3bd80">2</a>
</div>

| Symbol     | Meaning                              | Unit |
|------------|--------------------------------------|------|
| \\(r\\)    | Reference signal                     | [m]  |
| \\(r\_f\\) | Filtered reference signal            | [m]  |
| \\(e\\)    | Error signal                         | [m]  |
| \\(u\\)    | Control force that should be applied | [N]  |
| \\(v\\)    | Real force that is applied           | [N]  |
| \\(x\\)    | Plant output motion                  | [m]  |
| \\(y\\)    | Measured output motion               | [m]  |
| \\(y\_m\\) | Measurement value                    | [m]  |

<a id="orgee3bd80"></a>

{{< figure src="/ox-hugo/schmidt20_walk_control_loop.svg" caption="Figure 2: Block diagram of a motion control system, including feedforward and feedback control." >}}

The plant combines the mechanical structure, amplifiers and actuators, as they all deal with energy conversion in close interaction (Figure [3](#org22eead3)).
They interact in both directions in such a way that each element not only determines the input of the next element, but also influences the previous element by its dynamic load.

<a id="org22eead3"></a>

{{< figure src="/ox-hugo/schmidt20_energy_actuator_system.svg" caption="Figure 3: The energy converting part of a mechatronic system consists of a the amplifier, the actuator and the mechanical structure." >}}


#### Poles and Zeros in Motion Control {#poles-and-zeros-in-motion-control}

Any transfer function derived from a system can be represented with poles \\(p\_n\\) and zeros \\(z\_m\\):

\begin{equation}
G(s) = \frac{(s-z\_1)(s-z\_2)\dots(s-z\_m)}{(s-p\_1)(s-p\_2)\dots(s-p\_n)}
\end{equation}

with \\(m < n\\).

The number of poles is an indicator of the order of the dynamic system, corresponding to the number of states (position and velocity) and the number of energy containers (mass, spring).
All real system are _strictly proper_ with more poles and zeros.
Even though zeros can not create instability, the term _unstable zeros_ is given to zeros in the right half of the Laplace-plane (positive real term) for two reasons:

-   inverting an unstable zero will result in an unstable pole
-   it indicates non-minimum phase behavior, meaning a larger negative phase shift than would be expected from the slope of the amplitude Bode plot.

It also shows a counter intuitive step response, because the initial motion is directed opposite to the direction of the force.

It is usually caused by the non-collocated sensor in respect to the actuator.
In reality all mechatronic feedback systems have not perfectly collocated sensors and as a consequence they may show some level of non-minimum phase behaviour.
Fortunately the effect is mostly so small that it can be neglected.


#### Overview Feedforward Control {#overview-feedforward-control}

{{< figure src="/ox-hugo/schmidt20_feedforward_control_diagram.svg" >}}

Feedforward control is a very useful and preferred first step in the control of a complex dynamic motion system as it provides the following advantages:

-   **Less feedback required**: the better the feedforward part is performing the smaller the feedback error will need to be corrected further errors. This is the most important reason that feedforward control is always applied to the maximum accuracy possible in fast high precision motion systems.
-   **No sensor required**: no sensor information is fed back to the system, which means that a sensor can be left out, thus reducing the cost of pure feedforward controlled systems.
-   **Predictable movement**: if the reference signal (trajectory) is known in advance, the phase-lag and time delay in the system can be predicted and therefore compensated.
-   **No introduction of instability**: the poles of the controlled system are not changed by feedforward control. Therefore no instability can be introduced.
-   **No feeding back of sensor noise**: in precision motion systems, positioning noise is a critical point that always has to be considered in the control design. The lack of a sensor avoid insertion of the measurement noise in the system.

The drawbacks and limitations of feedforward control are:

-   **Limitation to inverted low-pass minimum-phase characteristic**:  it is not possible nor wise to create a controller with a very high gain at very high frequencies. Inverting unstable zeros for a non-minimum phase system would create an unstable controller.
-   **The plant has to be stable**: Unstable systems cannot be controlled with pure feedforward control.
-   **No compensation of model uncertainties**: Variations in the system dynamics, such as shifting of the resonance frequency or variation of the damping, are not monitored and therefore not accounted for in feedforward control.
-   **Can only compensate for known disturbances**: Disturbances of the motion system can only be compensated if they can be measured.


#### Overview Feedback Control {#overview-feedback-control}

{{< figure src="/ox-hugo/schmidt20_feedback_control_diagram.svg" >}}

Feedback is an addition to feedforward control with the following benefits:

-   **Stabilization of unstable systems**: As feedback control enables to determine the place of the closed-loop poles of the controlled system, unstable poles can be stabilised.
-   **Reduction of the effect of disturbances**: Disturbances of the controlled motion system are observed in the sensor signal, and therefore the feedback controller can compensate for them.
-   **Handling of uncertainties**: Feedback controlled systems can also be designed for _robustness_, which means that the stability and performance requirements are guaranteed even for parameter variations of the controlled mechatronic system.

Also, some pitfalls have to be dealt with:

-   **A sensor is required**: The feedback loop is closed, based on the information from a sensor. Therefore, feedback control can be only as good as the quality of the sensor signal allows. In precision positioning systems accurate sensors are required with high resolution and fast response, which are very costly. The measurement and sensing system often takes a substantial part of the total systems budget.
-   **Limited reaction speed**: A feedback controller only reacts on difference between the reference signal and the measured system status, which means that the error has to occur first before the controller can correct for it.
-   **Feedback of noise**: By closing the loop, the positioning noise of the motion system as well as sensor noise are also fed back, which has to be considered at the system and control design.
-   **Can introduce instability**: Just as feedback control can stabilize an unstable system, it can also destabilize a stable plant.
-   **Can increase errors**: With higher order systems feedback will reduce errors in the frequency band where the loop-gain is larger than one and increase errors just outside that band.


#### Summary {#summary}

<a id="table--tab:feedback-feedforward-summary"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:feedback-feedforward-summary">Table 2</a></span>:
  Summary of Feedback and Feedforward control
</div>

|                 | **Advantages**                          | **Limitations**                                              |
|-----------------|-----------------------------------------|--------------------------------------------------------------|
| **Feedback**    | Stabilization of unstable systems       | A sensor is required                                         |
|                 | Reduction of the effect of disturbances | Limited reaction speed                                       |
|                 | Handling of uncertainties               | Feedback of noise                                            |
|                 |                                         | Can introduce instability                                    |
|                 |                                         | Can increase errors                                          |
| **Feedforward** | Less feedback required                  | Limitation to inverted low-pass minimum-phase characteristic |
|                 | No sensor required                      | The plant has to be stable                                   |
|                 | Predictable movement                    | No compensation of model uncertainties                       |
|                 | No introduction of instability          | Can only compensate for known disturbances                   |
|                 | No feeding back of sensor noise         |                                                              |


### Feedforward Control {#feedforward-control}


#### Model-Based Feedforward Control {#model-based-feedforward-control}


#### Input-Shaping {#input-shaping}


#### Adaptive Feedforward Control {#adaptive-feedforward-control}


#### Trajectory Profile Generation {#trajectory-profile-generation}

The limitations of the actuators and electronics in a controlled motion system are usually related to limitations in the derivatives over time of the position:

-   \\(dx/dt\\) = Velocity
-   \\(d^2x/dt^2\\) = Acceleration
-   \\(d^3x/dt^3\\) = Jerk
-   \\(d^4x/dt^4\\) = Snap

Of at least the levels of Jerk and preferable also Snap should be limited.
The standard method to cope with these limitations involves shaping the input of a mechatronic motion system by means of _trajectory profile generation_ or _path-planning_.

Figure [4](#org473e6fa) shows a fourth order trajectory profile of a displacement, which means that all derivatives including the fourth derivative are defined in the path planning.
A third order trajectory would show a square profile for the jerk indicating an infinite Snap and the round of the acceleration would be gone.
A second order trajectory would show a square acceleration profile with infinite Jerk and sharp edges on the velocity.

<a id="org473e6fa"></a>

{{< figure src="/ox-hugo/schmidt20_trajectory_profile.svg" caption="Figure 4: Figure caption" >}}


### Feedback Control {#feedback-control}

> On might say that a high value of the unity-gain crossover frequency and corresponding high-frequency bandwidth limit is rather an unwanted side-effect of the required high loop-gain at lower frequencies, than a target for the design of a control system as such.


#### Sensitivity to Input Signals {#sensitivity-to-input-signals}


##### Sensitivity Functions {#sensitivity-functions}


##### Real Feedback Error Sensitivity {#real-feedback-error-sensitivity}


#### Stability and Robustness in Feedback Control {#stability-and-robustness-in-feedback-control}


##### Stability margins {#stability-margins}


### PID Feedback Control {#pid-feedback-control}


#### PID-Control of a Compact-Disc Player {#pid-control-of-a-compact-disc-player}


##### Relevant Sensitivity Functions {#relevant-sensitivity-functions}


##### Proportional Feedback {#proportional-feedback}


##### Proportional-Differential Feedback {#proportional-differential-feedback}


##### Limiting the Differentiating Action {#limiting-the-differentiating-action}


##### Adding I-Control {#adding-i-control}


#### PID-Control of a Spring Supported Mass {#pid-control-of-a-spring-supported-mass}


##### P-Control {#p-control}


##### D-Control {#d-control}


##### I-Control {#i-control}


##### Sensitivity Function Graphs {#sensitivity-function-graphs}


#### Limitations and Side Effects of PID-Feedback Control {#limitations-and-side-effects-of-pid-feedback-control}


##### Increased Sensitivity, the Waterbed Effect {#increased-sensitivity-the-waterbed-effect}


##### Integrator Wind-Up and Delays {#integrator-wind-up-and-delays}


#### PID-Control of a Fourth-Order Dynamic System {#pid-control-of-a-fourth-order-dynamic-system}


##### Controlling a Type III Dynamic System {#controlling-a-type-iii-dynamic-system}


##### Passive Damping {#passive-damping}


##### Shifting the Phase {#shifting-the-phase}


#### PID-Control of a Piezoelectric Actuator {#pid-control-of-a-piezoelectric-actuator}


##### Creating a Fourth-Order System {#creating-a-fourth-order-system}


#### PID-Control of a Magnetic Bearing {#pid-control-of-a-magnetic-bearing}


##### Frequency Response {#frequency-response}


##### Positive Stiffness by P-Control {#positive-stiffness-by-p-control}


##### D-Control and Pole Placement {#d-control-and-pole-placement}


##### I-control for Reduced Sensitivity {#i-control-for-reduced-sensitivity}


#### Optimisation by Loop-Shaping Design {#optimisation-by-loop-shaping-design}


##### Optimal Value of Alpha {#optimal-value-of-alpha}


##### Additional Low-Pass Filtering {#additional-low-pass-filtering}


##### Notching Filters {#notching-filters}


##### Peaking and Shelving Filters {#peaking-and-shelving-filters}


#### Design Steps for PID-control {#design-steps-for-pid-control}


### Digital Signal Processing - The Z-Domain {#digital-signal-processing-the-z-domain}


#### Continuous Time versus Discrete Time {#continuous-time-versus-discrete-time}

<a id="orgfdb177f"></a>

{{< figure src="/ox-hugo/schmidt20_digital_implementation.svg" caption="Figure 5: Overview of a digital implementation of a feedback controller, emphasising the analog-to-digital and digital-to-analog converters with their required analogue filters" >}}


#### Sampling of Continuous Signals {#sampling-of-continuous-signals}


#### Digital Number Representation {#digital-number-representation}

{{< figure src="/ox-hugo/schmidt20_digital_number_representation.svg" >}}


#### Digital Filter Theory {#digital-filter-theory}


##### Z-Transform and Difference Equations {#z-transform-and-difference-equations}


#### Finite Impulse Response (FIR) Filter {#finite-impulse-response--fir--filter}


#### Infinite Impulse Response (IIR) Filter {#infinite-impulse-response--iir--filter}


#### Converting Continuous to Discrete-Time Filters {#converting-continuous-to-discrete-time-filters}


### State-Space Feedback Control {#state-space-feedback-control}


#### State-Space in Relation to Motion Control {#state-space-in-relation-to-motion-control}


##### Mechanical Dynamic System in State-Space {#mechanical-dynamic-system-in-state-space}


##### PID-Control Feedback in State-Space {#pid-control-feedback-in-state-space}


#### State Feedback {#state-feedback}


##### System Identification {#system-identification}


##### State Estimation {#state-estimation}


##### Additional Remarks on State-Space Control {#additional-remarks-on-state-space-control}


### Conclusion on Motion Control {#conclusion-on-motion-control}

<summary>
Motion control is essential for Precision Mechatronic Systems and consists of two complementary elements:

-   **Extremely accurate Feedforward Control** is required when the motion system must execute a user defined motion to within maximum user defined position error limits.
    The forces required for this task are known upfront and can generally not be generated by feedback control only given the limited allowable position error and physical limitations on achievable loop-gain of feedback control.
-   **High Performance Feedback Control** is required when the motion system must be able to follow an unknown motion of a target, stabilize an otherwise unstable system and reduce the impact of disturbing forces and vibrations, such that the position error remains below a maximum user defined level.
    Due to the fact that a feedback controller can become unstable, sufficient robustness must be guaranteed.
    These is a conflicting relation between stability and performance.
</summary>


## Electromechanic Actuators {#electromechanic-actuators}


### Introduction {#introduction}


### Electromagnetics {#electromagnetics}


#### Hopkinson's Law {#hopkinson-s-law}


##### Practical Aspects of Hopkinson's Law {#practical-aspects-of-hopkinson-s-law}


##### Magnetic Energy {#magnetic-energy}


#### Ferromagnetic Materials {#ferromagnetic-materials}


##### Coil with Ferromagnetic Yoke {#coil-with-ferromagnetic-yoke}


##### Magnetisation Curve {#magnetisation-curve}


##### Permanent Magnets {#permanent-magnets}


#### Creating a Magnetic Field in an Air-Gap {#creating-a-magnetic-field-in-an-air-gap}


##### Optimal Use of Permanent Magnet Material {#optimal-use-of-permanent-magnet-material}


##### Flat Magnets Reduce Fringing Flux {#flat-magnets-reduce-fringing-flux}


##### Low Cost Loudspeaker Magnet {#low-cost-loudspeaker-magnet}


### Lorentz Actuator {#lorentz-actuator}


#### Lorentz Force {#lorentz-force}


##### Force from Flux-Linkage {#force-from-flux-linkage}


#### The Lorentz actuator as a Generator {#the-lorentz-actuator-as-a-generator}


#### Improving the Force of a Lorentz Actuator {#improving-the-force-of-a-lorentz-actuator}


##### The Moving-Coil Loudspeaker Actuator {#the-moving-coil-loudspeaker-actuator}


#### Position Dependency of the Lorentz Force {#position-dependency-of-the-lorentz-force}


##### Over-Hung and Under-Hung Coil {#over-hung-and-under-hung-coil}


#### Electronic Commutation {#electronic-commutation}


##### Three-Phase Electronic Control {#three-phase-electronic-control}


#### Figures of Merit of a Lorentz Actuator {#figures-of-merit-of-a-lorentz-actuator}


### Variable Reluctance Actuation {#variable-reluctance-actuation}


#### Reluctance Force in Lorentz Actuator {#reluctance-force-in-lorentz-actuator}


##### Eddy-Current Ring {#eddy-current-ring}


##### Ironless Stator {#ironless-stator}


#### Analytical Derivation of Reluctance Force {#analytical-derivation-of-reluctance-force}


#### Variable Reluctance Actuator. {#variable-reluctance-actuator-dot}


##### Electromagnetic Relay {#electromagnetic-relay}


##### Magnetic Attraction Force {#magnetic-attraction-force}


#### Permanent Magnet Biased Reluctance Actuator {#permanent-magnet-biased-reluctance-actuator}


##### Double Variable Reluctance Actuator {#double-variable-reluctance-actuator}


##### Constant Common Flux {#constant-common-flux}


##### Combining two Sources of Magnetic Flux {#combining-two-sources-of-magnetic-flux}


##### Hybrid Force Calculation {#hybrid-force-calculation}


##### Magnetic Bearings {#magnetic-bearings}


#### Active Linearisation of the Reluctance Force {#active-linearisation-of-the-reluctance-force}


### Application of Electromagnetic Actuators {#application-of-electromagnetic-actuators}


#### Electrical Interface Properties {#electrical-interface-properties}


##### Dynamic Effects of Self-Inductance {#dynamic-effects-of-self-inductance}


##### Limitation of the \`\`Jerk'' {#limitation-of-the-jerk}


##### Electromagnetic Damping {#electromagnetic-damping}


#### Comparison of three Electromagnetic Actuators {#comparison-of-three-electromagnetic-actuators}


##### Force-Constants {#force-constants}


##### Figures of Merit Including Mass {#figures-of-merit-including-mass}


##### Stiffness {#stiffness}


##### Repeatability and Predictability {#repeatability-and-predictability}


##### Dynamic Effects on the Control Loop {#dynamic-effects-on-the-control-loop}


### Piezoelectric Actuators {#piezoelectric-actuators}


#### Piezoelectricity {#piezoelectricity}


##### Poling {#poling}


##### Tapping the Bound Charge by Electrodes {#tapping-the-bound-charge-by-electrodes}


#### Transducer Models {#transducer-models}


#### Nonlinearity of Piezoelectric Actuators {#nonlinearity-of-piezoelectric-actuators}


##### Creep {#creep}


##### Hysteresis {#hysteresis}


##### Aging {#aging}


#### Mechanical Considerations {#mechanical-considerations}


##### Piezoelectric Actuator Stiffness {#piezoelectric-actuator-stiffness}


##### Actuator Types {#actuator-types}


##### Long Range Actuation by Friction {#long-range-actuation-by-friction}


##### Actuator Integration {#actuator-integration}


##### Mechanical Amplification {#mechanical-amplification}


##### Multiple Motion Directions by Stacking {#multiple-motion-directions-by-stacking}


#### Electrical Considerations {#electrical-considerations}


##### Charge vs. Voltage Control {#charge-vs-dot-voltage-control}


##### Self-Sensing Actuation {#self-sensing-actuation}


### Choosing the right Actuator Type {#choosing-the-right-actuator-type}


## Analogue Electronics in Mechatronic Systems {#analogue-electronics-in-mechatronic-systems}


### Introduction {#introduction}


### Passive Linear Electronics {#passive-linear-electronics}


#### Network Theory and Laws {#network-theory-and-laws}


##### Voltage Source {#voltage-source}


##### Current Source {#current-source}


##### Theorem of Norton and Thevenin {#theorem-of-norton-and-thevenin}


##### Kirchhoff's Laws {#kirchhoff-s-laws}


##### Impedances in Series or Parallel {#impedances-in-series-or-parallel}


##### Voltage Divider {#voltage-divider}


##### Maximum Power of a Real Voltage Source {#maximum-power-of-a-real-voltage-source}


#### Impedances in Electronic Circuits {#impedances-in-electronic-circuits}


##### Resistors {#resistors}


##### Capacitors {#capacitors}


##### Inductors {#inductors}


#### Passive Filters {#passive-filters}


##### Passive First-Order RC-Filters {#passive-first-order-rc-filters}


##### Passive Higher-Order RC-Filters {#passive-higher-order-rc-filters}


##### Passive LCR-Filters {#passive-lcr-filters}


#### Mechanical-Electrical Dynamic Analogy {#mechanical-electrical-dynamic-analogy}


### Semiconductors and Active Electronics {#semiconductors-and-active-electronics}


#### Basic Discrete Semiconductors {#basic-discrete-semiconductors}


##### Semiconductor Diode {#semiconductor-diode}


##### Bipolar Transistors {#bipolar-transistors}


##### MOSFET {#mosfet}


##### Other Discrete Semiconductors {#other-discrete-semiconductors}


#### Single Transistor Linear Amplifiers {#single-transistor-linear-amplifiers}


##### Emitter Follower {#emitter-follower}


##### Voltage Amplifier {#voltage-amplifier}


##### Differential Amplifier {#differential-amplifier}


#### Operational Amplifier {#operational-amplifier}


##### Basic Operational Amplifier Design {#basic-operational-amplifier-design}


##### Operational Amplifier with Feedback {#operational-amplifier-with-feedback}


#### Linear Amplifiers with Operational Amplifiers {#linear-amplifiers-with-operational-amplifiers}


##### Design Rules {#design-rules}


##### Non-Inverting Amplifier {#non-inverting-amplifier}


##### Inverting Amplifier {#inverting-amplifier}


##### Adding and Subtracting Signals {#adding-and-subtracting-signals}


##### Transimpedance Amplifier {#transimpedance-amplifier}


##### Transconductance Amplifier {#transconductance-amplifier}


#### Active Electronic Filters {#active-electronic-filters}


##### Integrator and First-Order Low-Pass {#integrator-and-first-order-low-pass}


##### Differentiator and First-Order High-Pass {#differentiator-and-first-order-high-pass}


#### Analogue PID-Controller {#analogue-pid-controller}


##### PID Transfer Function {#pid-transfer-function}


##### PID Control Gains {#pid-control-gains}


##### High-Speed PID-Control {#high-speed-pid-control}


#### Higher-order Electronic Filters {#higher-order-electronic-filters}


##### Second-Order Low-Pass Filter {#second-order-low-pass-filter}


##### Different Types of Active Filters {#different-types-of-active-filters}


#### Ideal and Real Operational Amplifiers {#ideal-and-real-operational-amplifiers}


##### Open-Loop Voltage Gain {#open-loop-voltage-gain}


##### Dynamic Limitations {#dynamic-limitations}


##### Input Related Limitations {#input-related-limitations}


##### Power Supply and Output Limitations {#power-supply-and-output-limitations}


#### Closing Remarks on Low-Power Electronics {#closing-remarks-on-low-power-electronics}


### Power Amplifiers for Motion Control {#power-amplifiers-for-motion-control}


#### Required Properties for Actuator Drive {#required-properties-for-actuator-drive}


##### Power Delivery Capability {#power-delivery-capability}


##### Dynamic Properties {#dynamic-properties}


##### Linearity, Freedom of Distortion {#linearity-freedom-of-distortion}


##### Voltage or Current Drive {#voltage-or-current-drive}


##### Efficiency {#efficiency}


##### Four-Quadrant Operation {#four-quadrant-operation}


##### Preferred Power Amplifier Principle {#preferred-power-amplifier-principle}


#### Switched-Mode Power Amplifiers {#switched-mode-power-amplifiers}


##### Power MOSFET, a Fast High-Power Switch {#power-mosfet-a-fast-high-power-switch}


##### Switching Sequence Generation {#switching-sequence-generation}


##### Voltage Drive Amplifier {#voltage-drive-amplifier}


##### Energy Flow in the Power Output Stage {#energy-flow-in-the-power-output-stage}


##### Intermediate Conclusions and Other Issues {#intermediate-conclusions-and-other-issues}


##### Driving the Power MOSFETs {#driving-the-power-mosfets}


##### Charge Pumping {#charge-pumping}


##### H-Bridge Configuration {#h-bridge-configuration}


##### Output Filter {#output-filter}


#### Resonant-Mode Power Amplifiers {#resonant-mode-power-amplifiers}


##### Switching Sequence of the Output Stage {#switching-sequence-of-the-output-stage}


##### Lossless Current Sensing {#lossless-current-sensing}


#### Three-Phase Amplifiers {#three-phase-amplifiers}


##### Concept of Three-Phase Amplifier {#concept-of-three-phase-amplifier}


##### Three-Phase Switching Power Stages {#three-phase-switching-power-stages}


#### Some Last Remarks on Power Electronics {#some-last-remarks-on-power-electronics}


## Optics in Mechatronic Systems {#optics-in-mechatronic-systems}


### Introduction {#introduction}


### Properties of Light and Light Sources {#properties-of-light-and-light-sources}


#### Light Generation by Thermal Radiation {#light-generation-by-thermal-radiation}


#### Photons by Electron Energy State Variation {#photons-by-electron-energy-state-variation}


##### Light Emitting Diodes {#light-emitting-diodes}


##### Laser as an Ideal Light Source {#laser-as-an-ideal-light-source}


#### Useful Power from a Light Source {#useful-power-from-a-light-source}


##### Radiant Emittance and Irradiance {#radiant-emittance-and-irradiance}


##### Radiance {#radiance}


##### Etendue {#etendue}


### Reflection and Refraction {#reflection-and-refraction}


#### Reflection and Refraction according to the Least Time {#reflection-and-refraction-according-to-the-least-time}


##### Partial Reflection and Refraction {#partial-reflection-and-refraction}


#### Concept of Wavefront {#concept-of-wavefront}


##### A Wavefront is Not Real {#a-wavefront-is-not-real}


### Geometric Optics {#geometric-optics}


#### Imaging with Refractive Lens Elements {#imaging-with-refractive-lens-elements}


##### Sign Conventions {#sign-conventions}


##### Real Lens Elements {#real-lens-elements}


##### Magnification {#magnification}


#### Aberrations {#aberrations}


##### Spherical Aberration {#spherical-aberration}


##### Astigmatism {#astigmatism}


##### Coma {#coma}


##### Geometric and Chromatic Aberrations {#geometric-and-chromatic-aberrations}


#### Combining Multiple Optical Elements {#combining-multiple-optical-elements}


##### Combining Two Positive Lenses {#combining-two-positive-lenses}


#### Aperture Stop and Pupil {#aperture-stop-and-pupil}


#### Telecentricity {#telecentricity}


##### Pupil, Aperture and Lens Dimensions {#pupil-aperture-and-lens-dimensions}


##### Practical Applications and Constraints {#practical-applications-and-constraints}


### Physical Optics {#physical-optics}


#### Polarisation {#polarisation}


##### Birefringence {#birefringence}


#### Interference {#interference}


##### Fabry-Perot Interferometer {#fabry-perot-interferometer}


#### Diffraction {#diffraction}


##### Amplitude gratings {#amplitude-gratings}


##### Phase Gratings {#phase-gratings}


##### Direction of the Incoming Light {#direction-of-the-incoming-light}


#### Imaging Quality based on Diffraction {#imaging-quality-based-on-diffraction}


##### Numerical Aperture and f-Number {#numerical-aperture-and-f-number}


##### Depth of Focus {#depth-of-focus}


### Adaptive Optics {#adaptive-optics}


#### Thermal Effects in Optical Imaging Systems {#thermal-effects-in-optical-imaging-systems}


#### Correcting the Wavefront {#correcting-the-wavefront}


##### Zernike Polynomials {#zernike-polynomials}


##### Correcting Zernikes by Adaptive Optics {#correcting-zernikes-by-adaptive-optics}


#### Adaptive Optics Principle of Operation {#adaptive-optics-principle-of-operation}


##### Active Mirrors {#active-mirrors}


## Measurement in Mechatronic Systems {#measurement-in-mechatronic-systems}


### Introduction {#introduction}


#### Measurement Systems {#measurement-systems}


#### Errors in Measurement Systems, Uncertainty {#errors-in-measurement-systems-uncertainty}


##### Uncertainty in Traceable Measurements {#uncertainty-in-traceable-measurements}


#### Functional Model of a Measurement System Element {#functional-model-of-a-measurement-system-element}


### Dynamic Error Budgeting {#dynamic-error-budgeting}


#### Error Statistics in Repeated Measurements {#error-statistics-in-repeated-measurements}


#### The Normal Distribution {#the-normal-distribution}


#### Combining Different Error Sources {#combining-different-error-sources}


#### Power Spectral Density and Cumulative Power {#power-spectral-density-and-cumulative-power}


#### Do not use the Cumulative Amplitude Spectrum! {#do-not-use-the-cumulative-amplitude-spectrum}


#### Variations in Dynamic Error Budgeting {#variations-in-dynamic-error-budgeting}


#### Sources of Noise and Disturbances {#sources-of-noise-and-disturbances}


##### Mechanical Noise {#mechanical-noise}


##### Electronic Noise {#electronic-noise}


### Sensor Signal Sensitivity {#sensor-signal-sensitivity}


#### Sensing Element {#sensing-element}


#### Converting an Impedance into an Electric Signal {#converting-an-impedance-into-an-electric-signal}


##### Wheatstone Bridge {#wheatstone-bridge}


#### Electronic Interconnection of Sensitive Signals {#electronic-interconnection-of-sensitive-signals}


##### Magnetic Disturbances {#magnetic-disturbances}


##### Capacitive Disturbances {#capacitive-disturbances}


##### Ground Loops {#ground-loops}


### Signal Conditioning {#signal-conditioning}


#### Instrumentation Amplifier {#instrumentation-amplifier}


#### Filtering and Modulation {#filtering-and-modulation}


##### AM with Square Wave Carrier {#am-with-square-wave-carrier}


##### AM with Sinusoidal Carrier {#am-with-sinusoidal-carrier}


### Signal Processing {#signal-processing}


#### Schmitt Trigger {#schmitt-trigger}


#### Digital Representation of Measurement Data {#digital-representation-of-measurement-data}


##### Gray Code {#gray-code}


##### Sampling of Analogue Values {#sampling-of-analogue-values}


##### Nyquist-Shannon Theorem {#nyquist-shannon-theorem}


##### Filtering to Prevent Aliasing {#filtering-to-prevent-aliasing}


#### Analogue-to-Digital Converters {#analogue-to-digital-converters}


##### Dual-Slope ADC {#dual-slope-adc}


##### Successive-Approximation ADC {#successive-approximation-adc}


##### Sigma-Delta ADC {#sigma-delta-adc}


##### ADC Latency in a Feedback Loop {#adc-latency-in-a-feedback-loop}


#### Connecting the Less Sensitive Elements {#connecting-the-less-sensitive-elements}


##### Characteristic Impedance {#characteristic-impedance}


##### Non-Galvanic Connection {#non-galvanic-connection}


### Short-Range Motion Sensors {#short-range-motion-sensors}


#### Optical Sensors {#optical-sensors}


##### Position Sensitive Detectors {#position-sensitive-detectors}


##### Optical Deflectometer {#optical-deflectometer}


#### Capacitive Position Sensors {#capacitive-position-sensors}


##### Linearising by Differential Measurement {#linearising-by-differential-measurement}


##### Accuracy Limits and Improvements {#accuracy-limits-and-improvements}


##### Sensing to Conductive Moving Plate {#sensing-to-conductive-moving-plate}


#### Inductive Position Sensors {#inductive-position-sensors}


##### Linear Variable Differential Transformer {#linear-variable-differential-transformer}


##### Eddy-Current Sensors {#eddy-current-sensors}


#### Pneumatic Proximity Sensor or Air-Gage {#pneumatic-proximity-sensor-or-air-gage}


### Measurement of Mechanical Dynamics {#measurement-of-mechanical-dynamics}


#### Measurement of Force and Strain {#measurement-of-force-and-strain}


##### Strain Gages {#strain-gages}


##### Fibre Bragg Grating Strain Measurement {#fibre-bragg-grating-strain-measurement}


#### Velocity Measurement {#velocity-measurement}


##### Geophone {#geophone}


#### Accelerometers {#accelerometers}


##### Closed-Loop Feedback Accelerometer {#closed-loop-feedback-accelerometer}


##### Piezoelectric Accelerometer {#piezoelectric-accelerometer}


##### MEMS Accelerometer {#mems-accelerometer}


### Optical Long-Range Incremental Position Sensors {#optical-long-range-incremental-position-sensors}


#### Linear Optical Encoders {#linear-optical-encoders}


##### Interpolation {#interpolation}


##### Vernier Resolution Enhancement {#vernier-resolution-enhancement}


##### Interferometric Optical Encoder {#interferometric-optical-encoder}


##### Concluding Remarks on Linear Encoders {#concluding-remarks-on-linear-encoders}


#### Laser Interferometer Measurement Systems {#laser-interferometer-measurement-systems}


##### Homodyne Distance Interferometry {#homodyne-distance-interferometry}


##### Heterodyne Distance Interferometry {#heterodyne-distance-interferometry}


##### Measurement Uncertainty {#measurement-uncertainty}


##### Configurations {#configurations}


##### Multi-Axis Laser Interferometers {#multi-axis-laser-interferometers}


#### Mechanical Aspects {#mechanical-aspects}


##### Abbe Error {#abbe-error}


## Precision Positioning in Wafer Scanners {#precision-positioning-in-wafer-scanners}


### Introduction {#introduction}


### The Waferscanner {#the-waferscanner}


#### Requirements on Precision {#requirements-on-precision}


### Dynamic Architecture {#dynamic-architecture}


#### Balance Masses {#balance-masses}


#### Vibration Isolation {#vibration-isolation}


##### Eigendynamics of the Sensitive Parts {#eigendynamics-of-the-sensitive-parts}


### Zero-Stiffness Stage Actuation {#zero-stiffness-stage-actuation}


#### Waferstage Actuation Concept {#waferstage-actuation-concept}


##### Waferstepper Long-Range Lorentz Actuator {#waferstepper-long-range-lorentz-actuator}


##### Multi-Axis Positioning {#multi-axis-positioning}


##### Long- and Short-Stroke Actuation {#long-and-short-stroke-actuation}


#### Full Magnetic Levitation {#full-magnetic-levitation}


#### Acceleration Limits of Reticle Stage {#acceleration-limits-of-reticle-stage}


### Position Measurement {#position-measurement}


#### Alignment Sensor {#alignment-sensor}


#### Keeping the Wafer in Focus {#keeping-the-wafer-in-focus}


#### Dual-Stage Measurement and Exposure {#dual-stage-measurement-and-exposure}


#### Long-Range Incremental Measurement System {#long-range-incremental-measurement-system}


##### Real-Time Metrology Loop {#real-time-metrology-loop}


### Motion Control {#motion-control}


#### Feedforward and Feedback Control {#feedforward-and-feedback-control}


##### Thermal, The Final Frontier {#thermal-the-final-frontier}


#### The Mass Dilemma {#the-mass-dilemma}

> A reduced mass requires improved system dynamics that enable a higher control bandwidth to compensate for the increase sensitivity for external vibrations.


### Future Developments in IC Lithography {#future-developments-in-ic-lithography}


### Main Design Rules for Precision {#main-design-rules-for-precision}


## Bibliography {#bibliography}

<a id="org9aaa5b5"></a>Schmidt, R Munnig, Georg Schitter, and Adrian Rankers. 2020. _The Design of High Performance Mechatronics - Third Revised Edition_. Ios Press.
